@@ -2,16 +2,17 @@
 /****** BEGIN USER CONFIGURATION SECTION *****/
 
 /*
- * You need to define the OS specific defines in the relevant
- * section.  These are being slowly removed, and converted to
- * auto-config, but for right now, this is needed.
+ * You need to uncomment the OS specific defines that correspond
+ * to the machine you are building nmh on.  These are being slowly
+ * removed, and converted to auto-config, but for right now,
+ * these are still needed.
  */
 
 /*
  * Solaris 2.x
  */
-#define SYS5  1
-#define SVR4  1
+/* #define SYS5  1 */
+/* #define SVR4  1 */
 
 /*
  * SunOS 4.1.x
@@ -34,7 +35,8 @@
 /* nmh IS CURRENTLY BROKEN ON LINUX */
 
 /*
- * FreeBSD 2.x, NetBSD 1.x, OpenBSD 2.x
+ * FreeBSD 2.x, NetBSD 1.x,
+ * OpenBSD 2.x, BSD/OS 2.x
  */
 /* #define BIND     1 */
 /* #define BSD42    1 */
@@ -161,6 +163,9 @@
 /* Define to 1 if tgetent() accepts NULL as a buffer */
 #undef TGETENT_ACCEPTS_NULL
 
+/* Define to 1 if you have reliable signals */
+#undef RELIABLE_SIGNALS
+
 /* Define to 1 if you use POSIX style signal handling */
 #undef POSIX_SIGNALS
  
