@@ -20,7 +20,7 @@ extern int tputs (char *cp, int affcnt, int (*outc) (int));
 /*
  * prototype from config.h
  */
-char *libpath(char *);
+char *etcpath(char *);
 
 /*
  * prototypes from the MH subroutine library
