@@ -11,10 +11,10 @@
 # include <setjmp.h>
 # include <stdio.h>
 # include <sys/types.h>
-# include "../mts/sendmail/smail.h"
+# include <mts/sendmail/smail.h>
 #else	/* MMDFMTS */
-# include "../mts/mmdf/util.h"
-# include "../mts/mmdf/mmdf.h"
+# include <mts/mmdf/util.h>
+# include <mts/mmdf/mmdf.h>
 #endif	/* MMDFMTS */
 
 #ifndef	MMDFI
