@@ -53,7 +53,7 @@ OfficialName (char *name)
     if (uleq (LocalName (), site))
 	return LocalName ();
 
-#ifdef	BSD41A
+#ifdef BSD41A
     if (rhost (&q) != NOTOK) {
 	strcpy (buffer, q);
 	free (q);
@@ -65,7 +65,7 @@ OfficialName (char *name)
 #ifndef	BIND
     sethostent (1);
 #endif
-    if (hp = gethostbyname (q)) {
+    if ((hp = gethostbyname (q))) {
 	strcpy (buffer, hp->h_name);
 	return buffer;
     }
@@ -105,9 +105,9 @@ init_hs (void)
 
     h = &hosts;
     while (fgets (buffer, sizeof buffer, fp) != NULL) {
-	if (cp = strchr(buffer, '#'))
+	if ((cp = strchr(buffer, '#')))
 	    *cp = 0;
-	if (cp = strchr(buffer, '\n'))
+	if ((cp = strchr(buffer, '\n')))
 	    *cp = 0;
 	for (cp = buffer; *cp; cp++)
 	    if (isspace (*cp))
@@ -118,14 +118,14 @@ init_hs (void)
 	    continue;
 
 	q = aliases;
-	if (cp = strchr(dp = cp, ' ')) {
+	if ((cp = strchr(dp = cp, ' '))) {
 	    *cp = 0;
 	    for (cp++; *cp; cp++) {
 		while (isspace (*cp))
 		    cp++;
 		if (*cp == 0)
 		    break;
-		if (cp = strchr(*q++ = cp, ' '))
+		if ((cp = strchr(*q++ = cp, ' ')))
 		    *cp = 0;
 		else
 		    break;
@@ -140,7 +140,7 @@ init_hs (void)
 	h = h->h_next;
 	h->h_name = getcpy (dp);
 	r = h->h_aliases =
-		(char **) calloc ((unsigned) (q - aliases + 1), sizeof *q);
+		(char **) calloc ((unsigned) (q - aliases + 1), sizeof(*q));
 	for (q = aliases; *q; q++)
 	    *r++ = getcpy (*q);
 	*r = 0;
