@@ -1,11 +1,11 @@
 
 /*
- * getcpy.c - copy a string in managed memory
+ * getcpy.c -- copy a string in managed memory
  *
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 
 char *
