@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 #define	BADMSG	(-2)
 #define	BADRNG	(-3)
