@@ -288,7 +288,7 @@ m_getfld (int state, unsigned char *name, unsigned char *buf,
 	    for (;;) {
 		cnt = iob->_cnt++; bp = (unsigned char *) --iob->_ptr;
 		c = cnt < i ? cnt : i;
-		while (ep = locc( c, bp, '\n' )) {
+		while ((ep = locc( c, bp, '\n' ))) {
 		    /*
 		     * if we hit the end of this field, return.
 		     */
@@ -356,7 +356,7 @@ m_getfld (int state, unsigned char *name, unsigned char *buf,
 		 * algorithms vs. brute force.)  Since I (currently)
 		 * run MH on a vax, we use the matchc instruction. --vj
 		 */
-		if (ep = matchc( fdelimlen, fdelim, c, bp ) )
+		if ((ep = matchc( fdelimlen, fdelim, c, bp )))
 		    c = ep - bp + 1;
 		else {
 		    /*
@@ -373,7 +373,7 @@ m_getfld (int state, unsigned char *name, unsigned char *buf,
 		     * (excluding the first and last), we do only one test.
 		     */
 		    ep = bp + c - 1;
-		    if (sp = pat_map[*ep]) {
+		    if ((sp = pat_map[*ep])) {
 			do {
 			    cp = sp;
 			    while (*--ep == *--cp)
@@ -501,7 +501,7 @@ m_unknown(FILE *iob)
 void
 m_eomsbr (int (*action)())
 {
-    if (eom_action = action) {
+    if ((eom_action = action)) {
 	msg_style = MS_MSH;
 	*msg_delim = 0;
 	fdelimlen = 1;
@@ -572,8 +572,8 @@ unixline (void)
     static char unixfrom[BUFSIZ];
 
     pp = unixfrom;
-    if (cp = dp = strchr(unixbuf, ' ')) {
-	while (cp = strchr(cp + 1, 'r'))
+    if ((cp = dp = strchr(unixbuf, ' '))) {
+	while ((cp = strchr(cp + 1, 'r')))
 	    if (strncmp (cp, "remote from ", 12) == 0) {
 		*cp = 0;
 		sprintf (pp, "%s!", cp + 12);
