@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 int msg_count = 0;	/* disgusting hack for "inc" so it can
 			 * know how many characters were stuffed
