@@ -17,7 +17,7 @@ int
 pidwait (pid_t id, int sigsok)
 {
     pid_t pid;
-    SIGNAL_HANDLER istat, qstat;
+    sigset_t set, oset;
 
 #ifdef WAITINT
     int status;
@@ -26,8 +26,11 @@ pidwait (pid_t id, int sigsok)
 #endif
 
     if (sigsok == NOTOK) {
-	istat = signal(SIGINT, SIG_IGN);
-	qstat = signal(SIGQUIT, SIG_IGN);
+	/* block a couple of signals */
+	sigemptyset (&set);
+	sigaddset (&set, SIGINT);
+	sigaddset (&set, SIGQUIT);
+	SIGPROCMASK (SIG_BLOCK, &set, &oset);
     }
 
 #ifdef HAVE_WAITPID
@@ -38,8 +41,8 @@ pidwait (pid_t id, int sigsok)
 #endif
 
     if (sigsok == NOTOK) {
-	signal(SIGINT, istat);
-	signal(SIGQUIT, qstat);
+	/* reset the signal mask */
+	SIGPROCMASK (SIG_SETMASK, &oset, &set);
     }
 
 #ifdef WAITINT
