@@ -5,11 +5,11 @@
  * $Id$
  */
 
+#include <h/mh.h>
+
 #define TO_LOWER 040
 #define NO_MASK  000
 
-#include <ctype.h>
-
 
 int
 uleq (char *c1, char *c2)
@@ -21,7 +21,7 @@ uleq (char *c1, char *c2)
     if (!c2)
 	c2 = "";
 
-    while (c = *c1++)
+    while ((c = *c1++))
     {
 #ifdef LOCALE
 	c &= 0xff;
