@@ -61,7 +61,7 @@ annosbr (int src, char *file, char *comp, char *text, int inplace, int datesw)
 
     if (datesw)
 	fprintf (tmp, "%s: %s\n", comp, dtimenow ());
-    if (cp = text) {
+    if ((cp = text)) {
 	do {
 	    while (*cp == ' ' || *cp == '\t')
 		cp++;
