@@ -6,6 +6,7 @@
  */
 
 #include <h/mh.h>
+#include <fcntl.h>
 
 static int  hdrfd = NOTOK;
 static int  txtfd = NOTOK;
@@ -135,10 +136,7 @@ ready_msg (char *msgnam)
 	adios (msgnam, "unable to open message");
 
     strcpy (tmpfil, m_tmpfil ("dist"));
-    if ((hdrfd = creat (tmpfil, 0600)) == NOTOK)
-	adios (tmpfil, "unable to create temporary file");
-    close (hdrfd);
-    if ((hdrfd = open (tmpfil, 2)) == NOTOK)
+    if ((hdrfd = open (tmpfil, O_RDWR | O_CREAT | O_TRUNC, 0600)) == NOTOK)
 	adios (tmpfil, "unable to re-open temporary file");
     if ((out = dup (hdrfd)) == NOTOK
 	    || (ofp = fdopen (out, "w")) == NULL)
@@ -168,11 +166,8 @@ ready_msg (char *msgnam)
 		fclose (ofp);
 
 		strcpy (tmpfil, m_tmpfil ("dist"));
-		if ((txtfd = creat (tmpfil, 0600)) == NOTOK)
-		    adios (tmpfil, "unable to create temporary file");
-		close (txtfd);
-		if ((txtfd = open (tmpfil, 2)) == NOTOK)
-		    adios (tmpfil, "unable to re-open temporary file");
+		if ((txtfd = open (tmpfil, O_RDWR | O_CREAT | O_TRUNC, 0600)) == NOTOK)
+		    adios (tmpfil, "unable to open temporary file");
 		if ((out = dup (txtfd)) == NOTOK
 			|| (ofp = fdopen (out, "w")) == NULL)
 		    adios (NULL, "no file descriptors -- you lose big");
