@@ -5,9 +5,9 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../h/formatsbr.h"
-#include "../zotnet/tws/tws.h"
+#include <h/mh.h>
+#include <h/formatsbr.h>
+#include <zotnet/tws/tws.h>
 
 #ifndef	MIME
 # define MIMEminc(a) (a)
@@ -19,98 +19,85 @@
 #define	VFORMAT	"digest-volume-%s"
 
 static struct swit switches[] = {
-#define	ANNOSW	0
-    "annotate", 0,
-#define	NANNOSW	1
-    "noannotate", 0,
+#define	ANNOSW                 0
+    { "annotate", 0 },
+#define	NANNOSW                1
+    { "noannotate", 0 },
+#define	DFOLDSW                2
+    { "draftfolder +folder", 0 },
+#define	DMSGSW                 3
+    { "draftmessage msg", 0 },
+#define	NDFLDSW                4
+    { "nodraftfolder", 0 },
+#define	EDITRSW                5
+    { "editor editor", 0 },
+#define	NEDITSW                6
+    { "noedit", 0 },
+#define	FILTSW                 7
+    { "filter filterfile", 0 },
+#define	FORMSW                 8
+    { "form formfile", 0 },
+#define	FRMTSW                 9
+    { "format", 5 },
+#define	NFRMTSW               10
+    { "noformat", 7 },
+#define	INPLSW                11
+    { "inplace", 0 },
+#define	NINPLSW               12
+    { "noinplace", 0 },
+#define	MIMESW                13
+    { "mime", MIMEminc(-4) },
+#define	NMIMESW               14
+    { "nomime", MIMEminc(-6) },
+#define	DGSTSW                15
+    { "digest list", 0 },
+#define	ISSUESW               16
+    { "issue number", 0 },
+#define	VOLUMSW               17
+    { "volume number", 0 },
+#define	WHATSW                18
+    { "whatnowproc program", 0 },
+#define	NWHATSW               19
+    { "nowhatnowproc", 0 },
+#define VERSIONSW             20
+    { "version", 0 },
+#define	HELPSW                21
+    { "help", 4 },
+#define	FILESW                22
+    { "file file", -4 },		/* interface from msh */
+#define	DASHSW                23
+    { "dashmunging", -4 },		/* interface to mhl */
+#define	NDASHSW               24
+    { "nodashmunging", -6 },
 
-#define	DFOLDSW	2
-    "draftfolder +folder", 0,
-#define	DMSGSW	3
-    "draftmessage msg", 0,
-#define	NDFLDSW	4
-    "nodraftfolder", 0,
+#ifdef MHE
+#define	BILDSW                25
+    { "build", -5 },			/* interface from mhe */
+#endif /* MHE */
 
-#define	EDITRSW	5
-    "editor editor", 0,
-#define	NEDITSW	6
-    "noedit", 0,
-
-#define	FILTSW	7
-    "filter filterfile", 0,
-#define	FORMSW	8
-    "form formfile", 0,
-
-#define	FRMTSW	9
-    "format", 5,
-#define	NFRMTSW	10
-    "noformat", 7,
-
-#define	INPLSW	11
-    "inplace", 0,
-#define	NINPLSW	12
-    "noinplace", 0,
-
-#define	MIMESW	13
-    "mime", MIMEminc(-4),
-#define	NMIMESW	14
-    "nomime", MIMEminc(-6),
-
-#define	DGSTSW	15
-    "digest list", 0,
-#define	ISSUESW	16
-    "issue number", 0,
-#define	VOLUMSW	17
-    "volume number", 0,
-
-#define	WHATSW	18
-    "whatnowproc program", 0,
-#define	NWHATSW	19
-    "nowhatnowproc", 0,
-
-#define VERSIONSW 20
-    "version", 0,
-#define	HELPSW	21
-    "help", 4,
-
-#define	FILESW	22
-    "file file", -4,		/* interface from msh */
-
-#define	DASHSW	23
-    "dashmunging", -4,		/* interface to mhl */
-#define	NDASHSW	24
-    "nodashmunging", -6,
-
-#ifdef	MHE
-#define	BILDSW	25
-    "build", -5,		/* interface from mhe */
-#endif	/* MHE */
-
-    NULL, 0
+    { NULL, 0 }
 };
 
 static struct swit aqrnl[] = {
-#define	NOSW	0
-    "quit", 0,
-#define	YESW	1
-    "replace", 0,
-#define	LISTDSW	2
-    "list", 0,
-#define	REFILSW	3
-    "refile +folder", 0,
-#define NEWSW	4
-    "new", 0,
-
-    NULL, 0
+#define	NOSW         0
+    { "quit", 0 },
+#define	YESW         1
+    { "replace", 0 },
+#define	LISTDSW      2
+    { "list", 0 },
+#define	REFILSW      3
+    { "refile +folder", 0 },
+#define NEWSW        4
+    { "new", 0 },
+    { NULL, 0 }
 };
 
 static struct swit aqrl[] = {
-    "quit", 0,
-    "replace", 0,
-    "list", 0,
-    "refile +folder", 0,
-
-    NULL, 0
+    { "quit", 0 },
+    { "replace", 0 },
+    { "list", 0 },
+    { "refile +folder", 0 },
+    { NULL, 0 }
 };
 
 static char drft[BUFSIZ];
@@ -133,42 +120,21 @@ static void mhl_draft(int, char *, int, int, char *, char *, int);
 
 main (int argc, char **argv)
 {
-    int     msgp = 0,
-            anot = 0,
-            inplace = 0,
-	    mime = 0,
-	    issue = 0,
-	    volume = 0,
-	    dashflg = 1,
-#ifdef	MHE
-	    buildsw = 0,
-#endif	/* MHE */
-	    nedit = 0,
-	    nwhat = 0,
-	    i,
-            in,
-            out,
-	    isdf = 0,
-            msgnum;
-    char   *cp,
-	   *cwd,
-           *maildir,
-	   *dfolder = NULL,
-	   *dmsg = NULL,
-	   *digest = NULL,
-           *ed = NULL,
-           *file = NULL,
-	   *filter = NULL,
-           *folder = NULL,
-           *form = NULL,
-            buf[100],
-	    value[10],
-          **ap,
-          **argp,
-           *arguments[MAXARGS],
-           *msgs[MAXARGS];
+    int msgp = 0, anot = 0, inplace = 0, mime = 0;
+    int issue = 0, volume = 0, dashflg = 1;
+    int nedit = 0, nwhat = 0, i, in;
+    int out, isdf = 0, msgnum;
+    char *cp, *cwd, *maildir, *dfolder = NULL;
+    char *dmsg = NULL, *digest = NULL, *ed = NULL;
+    char *file = NULL, *filter = NULL, *folder = NULL;
+    char *form = NULL, buf[100], value[10], **ap;
+    char **argp, *arguments[MAXARGS], *msgs[MAXARGS];
     struct stat st;
 
+#ifdef	MHE
+    int buildsw = 0;
+#endif	/* MHE */
+
 #ifdef LOCALE
 	setlocale(LC_ALL, "");
 #endif
@@ -238,7 +204,7 @@ main (int argc, char **argv)
 		case FILTSW:
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
-		    filter = getcpy (libpath (cp));
+		    filter = getcpy (etcpath (cp));
 		    mime = 0;
 		    continue;
 		case FORMSW: 
@@ -247,7 +213,7 @@ main (int argc, char **argv)
 		    continue;
 
 		case FRMTSW:
-		    filter = getcpy (libpath (mhlforward));
+		    filter = getcpy (etcpath (mhlforward));
 		    continue;
 		case NFRMTSW:
 		    filter = NULL;
@@ -390,7 +356,7 @@ try_it_again: ;
     m_setseq (mp);
 
 go_to_it: ;
-    if (filter && access (filter, 04) == NOTOK)
+    if (filter && access (filter, R_OK) == NOTOK)
 	adios (filter, "unable to read");
 
     if (digest) {
@@ -412,11 +378,11 @@ go_to_it: ;
     }
     else
 	if (form) {
-	    if ((in = open (libpath (form), 0)) == NOTOK)
+	    if ((in = open (etcpath (form), 0)) == NOTOK)
 		adios (form, "unable to open form file");
 	}
 	else {
-	    if ((in = open (libpath (forwcomps), 0)) == NOTOK)
+	    if ((in = open (etcpath (forwcomps), 0)) == NOTOK)
 		adios (forwcomps, "unable to open default components file");
 	    form = forwcomps;
 	}
