@@ -34,6 +34,7 @@
 
 #include <h/formatsbr.h>
 #include <h/scansbr.h>
+#include <h/signals.h>
 #include <zotnet/tws/tws.h>
 #include <zotnet/mts/mts.h>
 #include <errno.h>
@@ -449,7 +450,7 @@ main (int argc, char **argv)
     if (!(mp = m_gmsg (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
-#ifdef	POP
+#ifdef POP
 go_to_it: ;
     if (host == NULL)
 #endif	/* POP */
@@ -461,10 +462,10 @@ go_to_it: ;
     else {
 	locked++;
 	if (trnflag) {
-	    signal (SIGHUP, SIG_IGN);
-	    signal (SIGINT, SIG_IGN);
-	    signal (SIGQUIT, SIG_IGN);
-	    signal (SIGTERM, SIG_IGN);
+	    SIGNAL (SIGHUP, SIG_IGN);
+	    SIGNAL (SIGINT, SIG_IGN);
+	    SIGNAL (SIGQUIT, SIG_IGN);
+	    SIGNAL (SIGTERM, SIG_IGN);
 	}
 
 #ifdef MAILGROUP
@@ -493,13 +494,13 @@ go_to_it: ;
 #ifndef	POP
 	fprintf (aud, from ? "<<inc>> %s  -ms %s\n" : "<<inc>> %s\n",
 		dtimenow (), from);
-#else	/* POP */
+#else /* POP */
 	fprintf (aud, from ? "<<inc>> %s -ms %s\n"
 			: host ? "<<inc>> %s -host %s -user %s%s\n"
 			: "<<inc>> %s\n",
 		 dtimenow (), from ? from : host, user,
 		 rpop < 0 ? " -apop" : rpop > 0 ? " -rpop" : "");
-#endif	/* POP */
+#endif /* POP */
     }
 
 #ifdef MHE
@@ -522,7 +523,7 @@ go_to_it: ;
 	fflush (stdout);
     }
 
-#ifdef	POP
+#ifdef POP
     if (host) {
 	if (file) {
 	    file = path (file, TFILE);
@@ -658,7 +659,7 @@ go_to_it: ;
 	}
     }
     else {
-#endif	/* POP */
+#endif /* POP */
 
     m_unknown (in);		/* the MAGIC invocation... */
     hghnum = msgnum = mp->hghmsg;
@@ -725,9 +726,9 @@ go_to_it: ;
 	}
 	break;
     }
-#ifdef	POP
+#ifdef POP
     }
-#endif	/* POP */
+#endif /* POP */
 #ifndef	POP
     if (i < 0) {		/* error } */
 #else
@@ -757,14 +758,14 @@ go_to_it: ;
 #endif /* MHE */
     if (noisy)
 	fflush (stdout);
-#ifdef	POP
+#ifdef POP
     if (host && file)
 	done (0);
-#endif	/* POP */
+#endif /* POP */
 
-#ifdef	POP
+#ifdef POP
     if (host == NULL)
-#endif	/* POP */
+#endif /* POP */
     if (trnflag) {
 	if (stat (newmail, &st) != NOTOK && s1.st_mtime != st.st_mtime)
 	    advise (NULL, "new messages have arrived!\007");
@@ -793,9 +794,9 @@ go_to_it: ;
 	    m_setcur (mp, mp->curmsg);
     }
 
-#ifdef	POP
+#ifdef POP
     if (host == NULL)
-#endif	/* POP */
+#endif /* POP */
     if (locked)
 #ifdef MAILGROUP
     {
@@ -941,4 +942,4 @@ map_count (void)
     close (md);
     return (d.d_id);
 }
-#endif	/* POP */
+#endif /* POP */
