@@ -206,18 +206,20 @@ main (int argc, char **argv)
     if (listsw) {
 	int bits = FFATTRSLOT;
 
-	if (seqp == 0) {
-	    char *temp;
+#define empty(s) ((s) ? (s) : "")
 
+	if (!seqp) {
 	    for (i = 0; mp->msgattrs[i]; i++)
 		printf ("%s%s: %s\n", mp->msgattrs[i],
 			mp->attrstats & (1 << (bits + i)) ? " (private)" : "",
-			(temp = m_seq (mp, mp->msgattrs[i])) ? temp : "empty");
+			empty(m_seq(mp, mp->msgattrs[i])));
 	} else {
 	    for (seqp = 0; seqs[seqp]; seqp++)
-		printf ("%s: %s\n", seqs[seqp], m_seq (mp, seqs[seqp]));
+		printf ("%s: %s\n", seqs[seqp], empty(m_seq(mp, seqs[seqp])));
 	}
 
+#undef empty
+
 	if (debugsw)
 	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
 		if (mp->msgstats[msgnum] & SELECTED)
