@@ -49,51 +49,51 @@
 #define	QUOTE	'\\'
 
 static struct swit mhlswitches[] = {
-#define	BELLSW	0
+#define	BELLSW         0
     { "bell", 0 },
-#define	NBELLSW	1
+#define	NBELLSW        1
     { "nobell", 0 },
-#define	CLRSW	2
+#define	CLRSW          2
     { "clear", 0 },
-#define	NCLRSW	3
+#define	NCLRSW         3
     { "noclear", 0 },
-#define	FACESW	4
+#define	FACESW         4
     { "faceproc program", 0 },
-#define	NFACESW	5
+#define	NFACESW        5
     { "nofaceproc", 0 },
-#define	FOLDSW	6
+#define	FOLDSW         6
     { "folder +folder", 0 },
-#define	FORMSW	7
+#define	FORMSW         7
     { "form formfile", 0 },
-#define	PROGSW	8
+#define	PROGSW         8
     { "moreproc program", 0 },
-#define	NPROGSW	9
+#define	NPROGSW        9
     { "nomoreproc", 0 },
-#define	LENSW	10
+#define	LENSW         10
     { "length lines", 0 },
-#define	WIDSW	11
+#define	WIDSW         11
     { "width columns", 0 },
-#define	SLEEPSW	12
+#define	SLEEPSW       12
     { "sleep seconds",  0 },
-#define	DASHSW	13
+#define	DASHSW        13
     { "dashmunging", -4 },
-#define	NDASHSW	14
+#define	NDASHSW       14
     { "nodashmunging", -6 },
-#define VERSIONSW 15
+#define VERSIONSW     15
     { "version", 0 },
-#define	HELPSW	16
+#define	HELPSW        16
     { "help", 4 },
-#define	FORW1SW	17
+#define	FORW1SW       17
     { "forward", -7 },		/* interface from forw */
-#define	FORW2SW	18
+#define	FORW2SW       18
     { "forwall", -7 },		/*   .. */
-#define	DGSTSW	19
+#define	DGSTSW        19
     { "digest list", -6 },
-#define VOLUMSW 20
+#define VOLUMSW       20
     { "volume number", -6 },
-#define ISSUESW 21
+#define ISSUESW       21
     { "issue number", -5 },
-#define NBODYSW 22
+#define NBODYSW       22
     { "nobody", -6 },
     { NULL, 0 }
 };
@@ -440,15 +440,15 @@ mhl (int argc, char **argv)
     if (isatty (fileno (stdout)))
 	if (!nomore && !sc_hardcopy () && moreproc && *moreproc) {
 	    if (mhl_action) {
-		setsig (SIGINT, SIG_IGN);
-		setsig (SIGQUIT, quitser);
+		SIGNAL (SIGINT, SIG_IGN);
+		SIGNAL2 (SIGQUIT, quitser);
 	    }
 	    m_popen (moreproc);
 	    ontty = PITTY;
 	}
 	else {
-	    setsig (SIGINT, SIG_IGN);
-	    setsig (SIGQUIT, quitser);
+	    SIGNAL (SIGINT, SIG_IGN);
+	    SIGNAL2 (SIGQUIT, quitser);
 	    ontty = ISTTY;
 	}
     else
@@ -769,12 +769,12 @@ process (char *folder, char *fname, int ofilen, int ofilec)
 	    }
 	    cp = folder ? concat (folder, ":", fname, NULL) : getcpy (fname);
 	    if (ontty != PITTY)
-		signal (SIGINT, intrser);
-	    mhlfile (fp, cp, ofilen, ofilec);/* fall */
+		SIGNAL (SIGINT, intrser);
+	    mhlfile (fp, cp, ofilen, ofilec);  /* FALL THROUGH! */
 
 	default: 
 	    if (ontty != PITTY)
-		signal (SIGINT, SIG_IGN);
+		SIGNAL (SIGINT, SIG_IGN);
 	    if (mhl_action == NULL && fp != stdin)
 		fclose (fp);
 	    free (cp);
@@ -1395,13 +1395,12 @@ putch (char ch)
 static RETSIGTYPE
 intrser (int i)
 {
-#ifndef	BSD42
-    signal (SIGINT, intrser);
+#ifndef RELIABLE_SIGNALS
+    SIGNAL (SIGINT, intrser);
 #endif
 
     discard (stdout);
     putchar ('\n');
-
     longjmp (env, DONE);
 }
 
@@ -1409,8 +1408,8 @@ intrser (int i)
 static RETSIGTYPE
 pipeser (int i)
 {
-#ifndef	BSD42
-    signal (SIGPIPE, pipeser);
+#ifndef RELIABLE_SIGNALS
+    SIGNAL (SIGPIPE, pipeser);
 #endif
 
     done (NOTOK);
@@ -1420,13 +1419,12 @@ pipeser (int i)
 static RETSIGTYPE
 quitser (int i)
 {
-#ifndef	BSD42
-    signal (SIGQUIT, quitser);
+#ifndef RELIABLE_SIGNALS
+    SIGNAL (SIGQUIT, quitser);
 #endif
 
     putchar ('\n');
     fflush (stdout);
-
     done (NOTOK);
 }
 
@@ -1547,11 +1545,13 @@ doface (struct mcomp *c1)
 
     switch (child_id) {
 	case NOTOK: 
+	    /* oops... fork error */
 	    return NOTOK;
 
 	case OK: 
-	    signal (SIGINT, SIG_IGN);
-	    signal (SIGQUIT, SIG_IGN);
+	    /* child process */
+	    SIGNAL (SIGINT, SIG_IGN);
+	    SIGNAL (SIGQUIT, SIG_IGN);
 	    if (pdi[0] != fileno (stdin)) {
 		dup2 (pdi[0], fileno (stdin));
 		close (pdi[0]);
@@ -1577,6 +1577,7 @@ doface (struct mcomp *c1)
 	    _exit (-1);		/* NOTREACHED */
 
 	default: 
+	    /* parent process */
 	    close (pdi[0]);
 	    i = strlen (c1->c_text);
 	    if (write (pdi[1], c1->c_text, i) != i)
@@ -1626,7 +1627,7 @@ doface (struct mcomp *c1)
 
     return result;
 }
-#endif	/* not SOCKETS */
+#endif /* not SOCKETS */
 
 
 int
@@ -1644,20 +1645,25 @@ mhlsbr (int argc, char **argv, FP (*action)())
 	    digest = NULL;
 	    ontty = NOTTY;
 	    mhl_action = action;
-	    if ((istat = signal (SIGINT, SIG_IGN)) != SIG_DFL)
-		signal (SIGINT, istat);
-	    if ((qstat = signal (SIGQUIT, SIG_IGN)) != SIG_DFL)
-		signal (SIGQUIT, qstat);
-	    pstat = signal (SIGPIPE, pipeser);
-	    mhl (argc, argv);	/* fall */
+
+	    /*
+	     * If signal is at default action, then start ignoring
+	     * it, else let it set to its current action.
+	     */
+	    if ((istat = SIGNAL (SIGINT, SIG_IGN)) != SIG_DFL)
+		SIGNAL (SIGINT, istat);
+	    if ((qstat = SIGNAL (SIGQUIT, SIG_IGN)) != SIG_DFL)
+		SIGNAL (SIGQUIT, qstat);
+	    pstat = SIGNAL (SIGPIPE, pipeser);
+	    mhl (argc, argv);                  /* FALL THROUGH! */
 
 	default: 
-	    signal (SIGINT, istat);
-	    signal (SIGQUIT, qstat);
-	    signal (SIGPIPE, SIG_IGN);/* XXX */
+	    SIGNAL (SIGINT, istat);
+	    SIGNAL (SIGQUIT, qstat);
+	    SIGNAL (SIGPIPE, SIG_IGN);/* should probably change to block instead */
 	    if (ontty == PITTY)
 		m_pclose ();
-	    signal (SIGPIPE, pstat);
+	    SIGNAL (SIGPIPE, pstat);
 	    invo_name = cp;
 	    if (holder.c_text) {
 		free (holder.c_text);
@@ -1699,7 +1705,6 @@ mhldone (int status)
 static	int m_pid = NOTOK;
 static  int sd = NOTOK;
 
-
 static void
 m_popen (char *name)
 {
@@ -1716,8 +1721,8 @@ m_popen (char *name)
 	    adios ("fork", "unable to");
 
 	case OK: 
-	    signal (SIGINT, SIG_DFL);
-	    signal (SIGQUIT, SIG_DFL);
+	    SIGNAL (SIGINT, SIG_DFL);
+	    SIGNAL (SIGQUIT, SIG_DFL);
 
 	    close (pd[1]);
 	    if (pd[0] != fileno (stdin)) {
