@@ -368,18 +368,18 @@ main (int argc, char **argv)
 #ifdef	BSD42
     should_intr = 0;
 #endif	/* BSD42 */
-    setsigx (istat, SIGINT, intrser);
-    setsigx (qstat, SIGQUIT, quitser);
+    istat = SIGNAL2 (SIGINT, intrser);
+    qstat = SIGNAL2 (SIGQUIT, quitser);
 
     sc_width ();		/* MAGIC... */
 
     if (vmh = vmh1 && vmh2) {
 	rcinit (vmh1, vmh2);
 	pINI ();
-	signal (SIGINT, SIG_IGN);
-	signal (SIGQUIT, SIG_IGN);
+	SIGNAL (SIGINT, SIG_IGN);
+	SIGNAL (SIGQUIT, SIG_IGN);
 #ifdef	SIGTSTP
-	tstat = signal (SIGTSTP, SIG_IGN);
+	tstat = SIGNAL (SIGTSTP, SIG_IGN);
 #endif	/* SIGTSTP */
     }
 
@@ -1407,7 +1407,7 @@ getargs (char *prompt, struct swit *sw, struct Cmd *cmdp)
     told_to_quit = 0;
     for (;;) {
 	interrupted = 0;
-#ifdef	BSD42
+#ifdef BSD42
 	switch (setjmp (sigenv)) {
 	    case OK:
 		should_intr = 1;
@@ -1440,10 +1440,10 @@ getargs (char *prompt, struct swit *sw, struct Cmd *cmdp)
 		    kill (ppid, SIGEMT);
 		return EOF;
 	    }
-#else	/* BSD42 */
+#else /* BSD42 */
 	    if (i == EOF)
 		longjmp (sigenv, DONE);
-#endif	/* BSD42 */
+#endif /* BSD42 */
 	    if (cp < &buffer[sizeof buffer - 2])
 		*cp++ = i;
 	}
@@ -1691,7 +1691,7 @@ initaux_io (struct Cmd *cmdp)
 		cmdp->direction = STDIO;
 		return NOTOK;
 	    }
-	    signal (SIGPIPE, pipeser);
+	    SIGNAL (SIGPIPE, pipeser);
 	    broken_pipe = 0;
 	    break;
 
@@ -1740,7 +1740,7 @@ finaux_io (struct Cmd *cmdp)
 	    fflush (stdout);
 	    close (fileno (stdout));
 	    pclose (cmdp->stream);
-	    signal (SIGPIPE, SIG_DFL);
+	    SIGNAL (SIGPIPE, SIG_DFL);
 	    break;
 
 	default: 
@@ -1804,51 +1804,53 @@ m_setcur (struct msgs *mp, int msgnum)
 static RETSIGTYPE
 intrser (int i)
 {
-#ifndef	BSD42
-    signal (SIGINT, intrser);
-#endif	/* not BSD42 */
+#ifndef RELIABLE_SIGNALS
+    SIGNAL (SIGINT, intrser);
+#endif
 
     discard (stdout);
-
     interrupted++;
-#ifdef	BSD42
+
+#ifdef BSD42
     if (should_intr)
 	longjmp (sigenv, NOTOK);
-#endif	/* BSD42 */
+#endif
 }
 
 
 static RETSIGTYPE
 pipeser (int i)
 {
-#ifndef	BSD42
-    signal (SIGPIPE, pipeser);
-#endif	/* not BSD42 */
+#ifndef RELIABLE_SIGNALS
+    SIGNAL (SIGPIPE, pipeser);
+#endif
 
     if (broken_pipe++ == 0)
 	fprintf (stderr, "broken pipe\n");
     told_to_quit++;
     interrupted++;
-#ifdef	BSD42
+
+#ifdef BSD42
     if (should_intr)
 	longjmp (sigenv, NOTOK);
-#endif	/* BSD42 */
+#endif
 }
 
 
 static RETSIGTYPE
 quitser (int i)
 {
-#ifndef	BSD42
-    signal (SIGQUIT, quitser);
-#endif	/* BSD42 */
+#ifndef RELIABLE_SIGNALS
+    SIGNAL (SIGQUIT, quitser);
+#endif
 
     told_to_quit++;
     interrupted++;
-#ifdef	BSD42
+
+#ifdef BSD42
     if (should_intr)
 	longjmp (sigenv, NOTOK);
-#endif	/* BSD42 */
+#endif
 }
 
 
@@ -2159,7 +2161,7 @@ pFIN (void)
 
     switch (setjmp (peerenv)) {
 	case OK: 
-	    signal (SIGALRM, alrmser);
+	    SIGNAL (SIGALRM, alrmser);
 	    alarm (ALARM);
 
 	    status = peerwait ();
@@ -2227,9 +2229,9 @@ ttyNaux (struct Cmd *cmdp, char *s)
 	    done (1);		/* NOTREACHED */
     }
 
-#ifdef	SIGTSTP
-    signal (SIGTSTP, tstat);
-#endif	/* SIGTSTP */
+#ifdef SIGTSTP
+    SIGNAL (SIGTSTP, tstat);
+#endif
     return vmhtty;
 }
 
@@ -2241,9 +2243,9 @@ ttyR (struct Cmd *cmdp)
 
     rc = &rcs;
 
-#ifdef	SIGTSTP
-    signal (SIGTSTP, SIG_IGN);
-#endif	/* SIGTSTP */
+#ifdef SIGTSTP
+    SIGNAL (SIGTSTP, SIG_IGN);
+#endif
 
     if (vmhtty != OK)
 	return NOTOK;
@@ -2308,7 +2310,7 @@ winN (struct Cmd *cmdp, int n, int eof)
 	return NOTOK;
     }
 
-    switch (vmhpid = fork ()) {
+    switch (vmhpid = fork()) {
 	case NOTOK: 
 	    err2peer (RC_ERR, "fork", "unable to");
 	    close (pd[0]);
@@ -2317,7 +2319,7 @@ winN (struct Cmd *cmdp, int n, int eof)
 
 	case OK: 
 	    close (pd[1]);
-	    signal (SIGPIPE, SIG_IGN);
+	    SIGNAL (SIGPIPE, SIG_IGN);
 	    while ((i = read (pd[0], buffer, sizeof buffer)) > 0)
 		switch (rc2rc (RC_DATA, i, buffer, rc)) {
 		    case RC_ACK: 
@@ -2383,7 +2385,7 @@ winN (struct Cmd *cmdp, int n, int eof)
 
 	    if (cmdp && init_io (cmdp, 0) == NOTOK)
 		return NOTOK;
-	    pstat = signal (SIGPIPE, pipeser);
+	    pstat = SIGNAL (SIGPIPE, pipeser);
 	    broken_pipe = 1;
 
 	    close (pd[0]);
@@ -2422,7 +2424,7 @@ winR (struct Cmd *cmdp)
     clearerr (stderr);
     close (vmhfd2);
 
-    signal (SIGPIPE, pstat);
+    SIGNAL (SIGPIPE, pstat);
 
     if ((status = pidwait (vmhpid, OK)) == 2)
 	done (1);
