@@ -93,8 +93,8 @@ forkcmd (char **args, char *pgm)
 
 	case OK: 
 	    closefds (3);
-	    signal (SIGINT, istat);
-	    signal (SIGQUIT, qstat);
+	    SIGNAL (SIGINT, istat);
+	    SIGNAL (SIGQUIT, qstat);
 
 	    execvp (pgm, vec);
 	    fprintf (stderr, "unable to exec ");
@@ -1039,8 +1039,8 @@ forw (char *proc, char *filter, int vecp, char **vec)
 
 	    case OK: 
 		closefds (3);
-		signal (SIGINT, istat);
-		signal (SIGQUIT, qstat);
+		SIGNAL (SIGINT, istat);
+		SIGNAL (SIGQUIT, qstat);
 
 		vec[vecp++] = tmpfil;
 		vec[vecp] = NULL;
@@ -2526,9 +2526,10 @@ ask (int msgnum)
     }
     fflush (stdout);
     buf[0] = 0;
+
 #ifndef	BSD42
     read (fileno (stdout), buf, sizeof buf);
-#else	/* BSD42 */
+#else /* BSD42 */
     switch (setjmp (sigenv)) {
 	case OK: 
 	    should_intr = 1;
@@ -2538,7 +2539,8 @@ ask (int msgnum)
 	    should_intr = 0;
 	    break;
     }
-#endif	/* BSD42 */
+#endif /* BSD42 */
+
     if (strchr(buf, '\n') == NULL)
 	putchar ('\n');
 
@@ -3036,8 +3038,8 @@ ready: ;
 	    
 	case OK: 
 	    closefds (3);
-	    signal (SIGINT, istat);
-	    signal (SIGQUIT, qstat);
+	    SIGNAL (SIGINT, istat);
+	    SIGNAL (SIGQUIT, qstat);
 
 	    vec[vecp++] = tmpfil;
 	    vec[vecp] = NULL;
