@@ -5,8 +5,8 @@
  * $Id$
  */
 
-#include "../h/mh.h"
-#include "../zotnet/tws/tws.h"
+#include <h/mh.h>
+#include <zotnet/tws/tws.h>
 
 static struct swit parswit[] = {
 #define	PRAND                   0
