@@ -1535,7 +1535,7 @@ post (char *file, int bccque, int talk)
 }
 
 
-#ifdef	TMA
+#ifdef TMA
 static void
 postcipher (char *file, int bccque, int talk)
 {
@@ -1987,7 +1987,7 @@ do_an_address (struct mailname *lp, int talk, int tma)
 #endif	/* MMDFMTS */
 
 
-#ifdef	MHMTS
+#ifdef MHMTS
 
 static void
 do_an_address (struct mailname *lp, int talk, int tma)
@@ -2068,7 +2068,7 @@ do_an_address (struct mailname *lp, int talk, int tma)
 
     fflush (stdout);
 }
-#endif	/* MHMTS */
+#endif /* MHMTS */
 
 #ifdef SENDMTS
 
@@ -2078,9 +2078,9 @@ do_an_address (struct mailname *lp, int talk, int tma)
     int retval;
     register char *mbox, *host;
     char addr[BUFSIZ];
-#ifdef	TMA
+#ifdef TMA
     char reason[BUFSIZ];
-#endif	/* TMA */
+#endif /* TMA */
 
     switch (lp->m_type) {
 	case LOCALHOST: 
@@ -2102,7 +2102,7 @@ do_an_address (struct mailname *lp, int talk, int tma)
 	    break;
     }
 
-#ifdef	TMA
+#ifdef TMA
     if ((!whomsw || checksw)
 	    && tma
 	    && seekaddr (mbox, host, reason) == NOTOK) {
@@ -2110,7 +2110,7 @@ do_an_address (struct mailname *lp, int talk, int tma)
 		addr, "[TMA]", reason);
 	unkadr++;
     }
-#endif	/* TMA */
+#endif /* TMA */
 
     if (talk)
 	printf ("  %s%s", addr, whomsw && lp->m_bcc ? "[BCC]" : "");
@@ -2147,7 +2147,7 @@ do_an_address (struct mailname *lp, int talk, int tma)
 
     fflush (stdout);
 }
-#endif	/* SENDMTS */
+#endif /* SENDMTS */
 
 /*
  * SIGNAL HANDLING
@@ -2158,23 +2158,28 @@ do_an_address (struct mailname *lp, int talk, int tma)
 static RETSIGTYPE
 sigser (int i)
 {
-#ifndef	BSD42
-    signal (i, SIG_IGN);
-#endif	/* not BSD42 */
+#ifndef RELIABLE_SIGNALS
+    SIGNAL (i, SIG_IGN);
+#endif
+
     unlink (tmpfil);
     if (msgflags & MINV)
 	unlink (bccfil);
-#ifdef	MMDFMTS
+
+#ifdef MMDFMTS
     if (!whomsw || checksw)
 	mm_end (NOTOK);
-#endif	/* MMDFMTS */
-#ifdef	SENDMTS
+#endif /* MMDFMTS */
+
+#ifdef SENDMTS
     if (!whomsw || checksw)
 	sm_end (NOTOK);
-#endif	/* SENDMTS */
+#endif /* SENDMTS */
+
     done (1);
 }
-#endif	/* not MHMTS */
+
+#endif /* not MHMTS */
 
 
 static void
@@ -2184,16 +2189,16 @@ sigon (void)
 	return;
 
 #ifndef	MHMTS
-    setsigx (hstat, SIGHUP, sigser);
-    setsigx (istat, SIGINT, sigser);
-    setsigx (qstat, SIGQUIT, sigser);
-    setsigx (tstat, SIGTERM, sigser);
-#else	/* MHMTS */
-    setsigx (hstat, SIGHUP, SIG_IGN);
-    setsigx (istat, SIGINT, SIG_IGN);
-    setsigx (qstat, SIGQUIT, SIG_IGN);
-    setsigx (tstat, SIGTERM, SIG_IGN);
-#endif	/* MHMTS */
+    hstat = SIGNAL2 (SIGHUP, sigser);
+    istat = SIGNAL2 (SIGINT, sigser);
+    qstat = SIGNAL2 (SIGQUIT, sigser);
+    tstat = SIGNAL2 (SIGTERM, sigser);
+#else /* MHMTS */
+    hstat = SIGNAL2 (SIGHUP, SIG_IGN);
+    istat = SIGNAL2 (SIGINT, SIG_IGN);
+    qstat = SIGNAL2 (SIGQUIT, SIG_IGN);
+    tstat = SIGNAL2 (SIGTERM, SIG_IGN);
+#endif /* MHMTS */
 }
 
 
@@ -2203,10 +2208,10 @@ sigoff (void)
     if (debug)
 	return;
 
-    signal (SIGHUP, hstat);
-    signal (SIGINT, istat);
-    signal (SIGQUIT, qstat);
-    signal (SIGTERM, tstat);
+    SIGNAL (SIGHUP, hstat);
+    SIGNAL (SIGINT, istat);
+    SIGNAL (SIGQUIT, qstat);
+    SIGNAL (SIGTERM, tstat);
 }
 
 /* FCC INTERACTION */
@@ -2550,7 +2555,7 @@ uucpmail (struct mailname *lp, int talk, int fd, int from)
 	return;
     }
 
-    pstat = signal (SIGPIPE, SIG_IGN);
+    pstat = SIGNAL (SIGPIPE, SIG_IGN);
     if (from) {			/* no mail filtering, so... */
 	sprintf (buffer, "From %s %.24s remote from %s\n",
 		getusr (), ctime (&tclock), SystemName ());
@@ -2573,7 +2578,7 @@ uucpmail (struct mailname *lp, int talk, int fd, int from)
 	}
     if (pclose (fp))
 	goto oops;
-    signal (SIGPIPE, pstat);
+    SIGNAL (SIGPIPE, pstat);
 
     if (i < 0) {
 	if (!talk)
