@@ -135,10 +135,10 @@ main (int argc, char **argv)
     if (!(mp = m_gmsg (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
-    signal (SIGHUP, SIG_IGN);
-    signal (SIGINT, SIG_IGN);
-    signal (SIGQUIT, SIG_IGN);
-    signal (SIGTERM, SIG_IGN);
+    SIGNAL (SIGHUP, SIG_IGN);
+    SIGNAL (SIGINT, SIG_IGN);
+    SIGNAL (SIGQUIT, SIG_IGN);
+    SIGNAL (SIGTERM, SIG_IGN);
 
     tmpfilenam = m_scratch ("", invo_name);
     if ((fd = creat (tmpfilenam, m_gmprot ())) == NOTOK)
