@@ -166,6 +166,10 @@ main (int argc, char **argv)
 static RETSIGTYPE
 alrmser (int i)
 {
+#ifndef RELIABLE_SIGNALS
+    SIGNAL (SIGALRM, alrmser);
+#endif
+
     longjmp (myctx, DONE);
 }
 
@@ -201,7 +205,7 @@ message_fd (char **vec)
 
 	default: 
 	    if (!setjmp (myctx)) {
-		signal (SIGALRM, alrmser);
+		SIGNAL (SIGALRM, alrmser);
 		bytes = fstat(fileno (stdin), &st) != NOTOK ? (int) st.st_size : 100;
 		if (bytes <= 0)
 		    bytes = 100;
@@ -266,7 +270,7 @@ alert (char *tty, int md)
 	return;
 
     if (!setjmp (myctx)) {
-	signal (SIGALRM, alrmser);
+	SIGNAL (SIGALRM, alrmser);
 	alarm (2);
 	td = open (ttyspec, 1);
 	alarm (0);
@@ -296,7 +300,7 @@ alert (char *user, int md)
 
     if ((td = ttyw ("notify", NULL, NULL, user)) == NOTOK)
 	return;
-    signal (SIGPIPE, SIG_IGN);
+    SIGNAL (SIGPIPE, SIG_IGN);
 
     lseek (md, (off_t), 0);
     while ((i = read (md, buffer, sizeof buffer)) > 0)
