@@ -148,7 +148,7 @@ rmf (char *folder)
     others = 0;
 
     j = strlen(BACKUP_PREFIX);
-    while (dp = readdir (dd)) {
+    while ((dp = readdir (dd))) {
 	switch (dp->d_name[0]) {
 	    case '.': 
 		if (strcmp (dp->d_name, ".") == 0
