@@ -285,12 +285,12 @@ main (int argc, char **argv)
 
     if (dfolder == NULL) {
 	if (msgp == 0) {
-#ifdef	WHATNOW
+#ifdef WHATNOW
 	    if ((cp = getenv ("mhdraft")) && *cp) {
 		msgs[msgp++] = cp;
 		goto go_to_it;
 	    }
-#endif	/* WHATNOW */
+#endif /* WHATNOW */
 	    msgs[msgp++] = getcpy (m_draft (NULL, NULL, 1, &isdf));
 	    if (stat (msgs[0], &st) == NOTOK)
 		adios (msgs[0], "unable to stat draft file");
@@ -348,9 +348,9 @@ main (int argc, char **argv)
 
 	m_sync (mp);
     }
-#ifdef	WHATNOW
+#ifdef WHATNOW
 go_to_it: ;
-#endif	/* WHATNOW */
+#endif /* WHATNOW */
 
 
 #ifdef	TMA
@@ -371,7 +371,7 @@ go_to_it: ;
 	    if ((fp = fopen (buf, "r")) != NULL
 		&& fgets (buf, sizeof buf, fp) != NULL) {
 		    fclose (fp);
-		    if (cp = index (buf, '\n'))
+		    if (cp = strchr (buf, '\n'))
 			*cp = 0;
 		    m_putenv ("SIGNATURE", buf);
 	    }
