@@ -362,10 +362,10 @@ alert (char *file, int out)
 	    advise ("fork", "unable to");
 
 	case OK: 		/* send it */
-	    signal (SIGHUP, SIG_IGN);
-	    signal (SIGINT, SIG_IGN);
-	    signal (SIGQUIT, SIG_IGN);
-	    signal (SIGTERM, SIG_IGN);
+	    SIGNAL (SIGHUP, SIG_IGN);
+	    SIGNAL (SIGINT, SIG_IGN);
+	    SIGNAL (SIGQUIT, SIG_IGN);
+	    SIGNAL (SIGTERM, SIG_IGN);
 	    if (forwsw)
 		if ((in = open (file, 0)) == NOTOK)
 		    admonish (file, "unable to re-open");
@@ -422,7 +422,7 @@ static void
 anno (int fd, struct stat *st)
 {
     pid_t child_id;
-    SIGNAL_HANDLER hstat, istat, qstat, tstat;
+    sigset_t set, oset;
     static char *cwd = NULL;
     struct stat st2;
 
@@ -446,19 +446,20 @@ anno (int fd, struct stat *st)
 		cwd = getcpy (pwd ());
 
 	case OK: 
-	    hstat = signal (SIGHUP, SIG_IGN);
-	    istat = signal (SIGINT, SIG_IGN);
-	    qstat = signal (SIGQUIT, SIG_IGN);
-	    tstat = signal (SIGTERM, SIG_IGN);
+	    /* block a few signals */
+	    sigemptyset (&set);
+	    sigaddset (&set, SIGHUP);
+	    sigaddset (&set, SIGINT);
+	    sigaddset (&set, SIGQUIT);
+	    sigaddset (&set, SIGTERM);
+	    SIGPROCMASK (SIG_BLOCK, &set, &oset);
 
 	    annoaux (fd);
 	    if (child_id == OK)
 		_exit (0);
 
-	    signal (SIGHUP, hstat);
-	    signal (SIGINT, istat);
-	    signal (SIGQUIT, qstat);
-	    signal (SIGTERM, tstat);
+	    /* reset the signal mask */
+	    SIGPROCMASK (SIG_SETMASK, &oset, &set);
 
 	    chdir (cwd);
 	    break;
