@@ -24,17 +24,17 @@
 #include <h/mh.h>
 #include <h/dropsbr.h>
 #include <h/rcvmail.h>
+#include <h/signals.h>
 #include <zotnet/tws/tws.h>
 #include <zotnet/mts/mts.h>
+
 #include <pwd.h>
 #include <signal.h>
 #include <sys/ioctl.h>
 #include <utmp.h>
-
 #include <ndbm.h>
 #include <fcntl.h>
 
-
 static struct swit switches[] = {
 #define	ADDRSW         0
     { "addr address", 0 },
@@ -968,7 +968,7 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 
 	default: 
 	    if (!setjmp (myctx)) {
-		signal (SIGALRM, alrmser);
+		SIGNAL (SIGALRM, alrmser);
 		bytes = fstat (fd, &st) != NOTOK ? (int) st.st_size : 100;
 		if (bytes <= 0)
 		    bytes = 100;
@@ -1006,6 +1006,10 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 static RETSIGTYPE
 alrmser (int i)
 {
+#ifndef RELIABLE_SIGNALS
+    SIGNAL (SIGALRM, alrmser);
+#endif
+
     longjmp (myctx, DONE);
 }
 
