@@ -528,7 +528,7 @@ arginit (char **vec)
 
     for (i = 0; *vec; vec++) {
 #ifdef	MHMTS
-	if (ap = index (*vec, '.'))
+	if (ap = strchr (*vec, '.'))
 	    *vec = ++ap;
 #endif	MHMTS
 	make_lower (addr, *vec);
