@@ -8,12 +8,12 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 #include <signal.h>
-#include "../h/addrsbr.h"
-#include "../h/aliasbr.h"
-#include "../h/dropsbr.h"
-#include "../zotnet/tws/tws.h"
+#include <h/addrsbr.h>
+#include <h/aliasbr.h>
+#include <h/dropsbr.h>
+#include <zotnet/tws/tws.h>
 
 #define	uptolow(c)	((isalpha(c) && isupper (c)) ? tolower (c) : c)
 
@@ -21,81 +21,63 @@
 #define FCCS		10	/* max number of fccs allowed */
 
 struct swit switches[] = {
-#define	FILTSW	0
-    "filter filterfile", 0,
-#define	NFILTSW	1
-    "nofilter", 0,
-
-#define	FRMTSW	2
-    "format", 0,
-#define	NFRMTSW	3
-    "noformat", 0,
-
-#define	REMVSW	4
-    "remove", 0,
-#define	NREMVSW	5
-    "noremove", 0,
-
-#define	VERBSW	6
-    "verbose", 0,
-#define	NVERBSW	7
-    "noverbose", 0,
-
-#define	WATCSW	8
-    "watch", 0,
-#define	NWATCSW	9
-    "nowatch", 0,
-
-#define BACKSW 10
-    "backup", 0,
-#define NBACKSW 11
-    "nobackup", 0,
-
-#define ALIASW 12
-    "alias aliasfile", 0,
-#define NALIASW 13
-    "noalias", 0,
-
-#define WIDTHSW 14
-    "width columns", 0,
-
-#define VERSIONSW 15
-    "version", 0,
-#define	HELPSW	16
-    "help", 4,
-
-#define	DEBUGSW	17
-    "debug", -5,
-
-#define	DISTSW	18
-    "dist", -4,			/* interface from dist */
-
-#define CHKSW 19
-    "check", -5,		/* interface from whom */
-#define NCHKSW 20
-    "nocheck", -7,		/* interface from whom */
-#define WHOMSW 21
-    "whom", -4,			/* interface from whom */
-
-#define PUSHSW 22		/* fork to sendmail then exit */
-    "push", -4,
-#define NPUSHSW 23		/* exec sendmail */
-    "nopush", -6,
-
-#define LIBSW 24
-    "library directory", -7,
-
-#define	ANNOSW	25
-    "idanno number", -6,
-
-    NULL, 0
+#define	FILTSW               0
+    { "filter filterfile", 0 },
+#define	NFILTSW              1
+    { "nofilter", 0 },
+#define	FRMTSW               2
+    { "format", 0 },
+#define	NFRMTSW              3
+    { "noformat", 0 },
+#define	REMVSW               4
+    { "remove", 0 },
+#define	NREMVSW              5
+    { "noremove", 0 },
+#define	VERBSW               6
+    { "verbose", 0 },
+#define	NVERBSW              7
+    { "noverbose", 0 },
+#define	WATCSW               8
+    { "watch", 0 },
+#define	NWATCSW              9
+    { "nowatch", 0 },
+#define BACKSW              10
+    { "backup", 0 },
+#define NBACKSW             11
+    { "nobackup", 0 },
+#define ALIASW              12
+    { "alias aliasfile", 0 },
+#define NALIASW             13
+    { "noalias", 0 },
+#define WIDTHSW             14
+    { "width columns", 0 },
+#define VERSIONSW           15
+    { "version", 0 },
+#define	HELPSW              16
+    { "help", 4 },
+#define	DEBUGSW             17
+    { "debug", -5 },
+#define	DISTSW              18
+    { "dist", -4 },		/* interface from dist */
+#define CHKSW               19
+    { "check", -5 },		/* interface from whom */
+#define NCHKSW              20
+    { "nocheck", -7 },		/* interface from whom */
+#define WHOMSW              21
+    { "whom", -4 },		/* interface from whom */
+#define PUSHSW              22	/* fork to sendmail then exit */
+    { "push", -4 },
+#define NPUSHSW             23	/* exec sendmail */
+    { "nopush", -6 },
+#define LIBSW               24
+    { "library directory", -7 },
+#define	ANNOSW              25
+    { "idanno number", -6 },
+    { NULL, 0 }
 };
 
 
-struct headers {
-    char   *value;
-
-    unsigned int    flags;
+/* flags for headers->flags */
 #define	HNOP	0x0000		/* just used to keep .set around */
 #define	HBAD	0x0001		/* bad header - don't let it through */
 #define	HADR	0x0002		/* header has an address field */
@@ -108,63 +90,66 @@ struct headers {
 #define	HNIL	0x0100		/* okay for this header not to have addrs */
 #define	HIGN	0x0200		/* ignore this header */
 
-    unsigned int    set;
+/* flags for headers->set */
 #define	MFRM	0x0001		/* we've seen a From: */
 #define	MDAT	0x0002		/* we've seen a Date: */
 #define	MRFM	0x0004		/* we've seen a Resent-From: */
 #define	MVIS	0x0008		/* we've seen sighted addrs */
 #define	MINV	0x0010		/* we've seen blind addrs */
 #define	MRDT	0x0020		/* we've seen a Resent-Date: */
+
+struct headers {
+    char *value;
+    unsigned int flags;
+    unsigned int set;
 };
 
 
-static struct headers  NHeaders[] = {
-    "Return-Path", HBAD, 0,
-    "Received", HBAD, 0,
-    "Reply-To", HADR | HNGR, 0,
-    "From", HADR | HNGR, MFRM,
-    "Sender", HADR | HBAD, 0,
-    "Date", HNOP, MDAT,
-    "Subject", HSUB, 0,
-    "To", HADR | HTRY, MVIS,
-    "cc", HADR | HTRY, MVIS,
-    "Bcc", HADR | HTRY | HBCC | HNIL, MINV,
-    "Message-Id", HBAD, 0,
-    "Fcc", HFCC, 0,
-
+static struct headers NHeaders[] = {
+    { "Return-Path", HBAD,                0 },
+    { "Received",    HBAD,                0 },
+    { "Reply-To",    HADR|HNGR,           0 },
+    { "From",        HADR|HNGR,           MFRM },
+    { "Sender",      HADR|HBAD,           0 },
+    { "Date",        HNOP,                MDAT },
+    { "Subject",     HSUB,                0 },
+    { "To",          HADR|HTRY,           MVIS },
+    { "cc",          HADR|HTRY,           MVIS },
+    { "Bcc",         HADR|HTRY|HBCC|HNIL, MINV },
+    { "Message-Id",  HBAD,                0 },
+    { "Fcc",         HFCC,                0 },
     NULL
 };
 
-static struct headers  RHeaders[] = {
-    "Resent-Reply-To", HADR | HNGR, 0,
-    "Resent-From", HADR | HNGR, MRFM,
-    "Resent-Sender", HADR | HBAD, 0,
-    "Resent-Date", HNOP, MRDT,
-    "Resent-Subject", HSUB, 0,
-    "Resent-To", HADR | HTRY, MVIS,
-    "Resent-cc", HADR | HTRY, MVIS,
-    "Resent-Bcc", HADR | HTRY | HBCC, MINV,
-    "Resent-Message-Id", HBAD, 0,
-    "Resent-Fcc", HFCC, 0,
-    "Reply-To", HADR, 0,
-    "Fcc", HIGN, 0,
-
+static struct headers RHeaders[] = {
+    { "Resent-Reply-To",   HADR|HNGR,      0 },
+    { "Resent-From",       HADR|HNGR,      MRFM },
+    { "Resent-Sender",     HADR|HBAD,      0 },
+    { "Resent-Date",       HNOP,           MRDT },
+    { "Resent-Subject",    HSUB,           0 },
+    { "Resent-To",         HADR|HTRY,      MVIS },
+    { "Resent-cc",         HADR|HTRY,      MVIS },
+    { "Resent-Bcc",        HADR|HTRY|HBCC, MINV },
+    { "Resent-Message-Id", HBAD,           0 },
+    { "Resent-Fcc",        HFCC,           0 },
+    { "Reply-To",          HADR,           0 },
+    { "Fcc",               HIGN,           0 },
     NULL
 };
 
 
-static short    fccind = 0;	/* index into fccfold[] */
+static short fccind = 0;	/* index into fccfold[] */
 
-static int  badmsg = 0;		/* message has bad semantics */
-static int  verbose = 0;	/* spell it out */
-static int  debug = 0;		/* debugging post */
-static int  rmflg = 1;		/* remove temporary file when done */
-static int  watch = 0;		/* watch the delivery process */
-static int  backflg = 0;	/* rename input file as *.bak when done */
-static int  whomflg = 0;	/* if just checking addresses */
-static int  pushflg = 0;	/* if going to fork to sendmail */
-static int  aliasflg = -1;	/* if going to process aliases */
-static int  outputlinelen=72;
+static int badmsg = 0;		/* message has bad semantics            */
+static int verbose = 0;		/* spell it out                         */
+static int debug = 0;		/* debugging post                       */
+static int rmflg = 1;		/* remove temporary file when done      */
+static int watch = 0;		/* watch the delivery process           */
+static int backflg = 0;		/* rename input file as *.bak when done */
+static int whomflg = 0;		/* if just checking addresses           */
+static int pushflg = 0;		/* if going to fork to sendmail         */
+static int aliasflg = -1;	/* if going to process aliases          */
+static int outputlinelen=72;
 
 static unsigned msgflags = 0;	/* what we've seen */
 
@@ -180,7 +165,7 @@ static char *filter = NULL;	/* the filter for BCC'ing */
 static char *subject = NULL;	/* the subject field for BCC'ing */
 static char *fccfold[FCCS];	/* foldernames for FCC'ing */
 
-static struct headers  *hdrtab;	/* table for the message we're doing */
+static struct headers *hdrtab;	/* table for the message we're doing */
 static FILE *out;		/* output (temp) file */
 
 extern char *sendmail;
@@ -205,18 +190,11 @@ static void die (char *, char *, ...);
 
 main (int argc, char **argv)
 {
-    int     state,
-	    i,
-	    pid,
-            compnum;
-    char   *cp,
-           *msg = NULL,
-          **argp = argv + 1,
-	    *sargv[16],
-            buf[BUFSIZ],
-            name[NAMESZ],
-	    *arguments[MAXARGS];
-    FILE * in;
+    int state, i, pid, compnum;
+    char *cp, *msg = NULL, **argp = argv + 1;
+    char *sargv[16], buf[BUFSIZ], name[NAMESZ];
+    char *arguments[MAXARGS];
+    FILE *in;
 
 #ifdef LOCALE
 	setlocale(LC_ALL, "");
