@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/nmh.h"
+#include <h/nmh.h>
 
 #ifndef	BSD42
 # undef TTYD
