@@ -137,10 +137,10 @@ main (int argc, char **argv)
 
     closefds (fileno (stderr) + 1);
 
-    signal (SIGINT, SIG_IGN);
-    signal (SIGHUP, sigser);
-    signal (SIGQUIT, SIG_IGN);
-    signal (SIGTERM, sigser);
+    SIGNAL (SIGINT, SIG_IGN);
+    SIGNAL (SIGHUP, sigser);
+    SIGNAL (SIGQUIT, SIG_IGN);
+    SIGNAL (SIGTERM, sigser);
 
     switch (fork ()) {
 	case NOTOK: 
@@ -426,23 +426,17 @@ struct stat *st;
 	adios (mystat, "error writing");
 }
 
-/*  */
-
-#ifdef	BSD42
-/* ARGSUSED */
-#endif	BSD42
 
 static int  sigser (sig)
 int     sig;
 {
-#ifndef	BSD42
-    signal (sig, SIG_IGN);
-#endif	BSD42
+#ifndef RELIABLE_SIGNALS
+    SIGNAL (sig, SIG_IGN);
+#endif
 
     done (1);
 }
 
-/*  */
 
 void	done (status)
 int	status;
