@@ -347,8 +347,8 @@ PEERinit (int vecp, char *vec[])
 	    vec[vecp++] = buf2;
 	    vec[vecp] = NULL;
 
-	    signal (SIGINT, SIG_DFL);
-	    signal (SIGQUIT, SIG_DFL);
+	    SIGNAL (SIGINT, SIG_DFL);
+	    SIGNAL (SIGQUIT, SIG_DFL);
 
 	    vec[0] = r1bindex (vmhproc, '/');
 	    execvp (vmhproc, vec);
@@ -472,26 +472,28 @@ pTTY (struct record *r)
 
     TTYoff ();
 
-    hstat = signal (SIGHUP, SIG_IGN);
-    istat = signal (SIGINT, SIG_IGN);
-    qstat = signal (SIGQUIT, SIG_IGN);
-    tstat = signal (SIGTERM, SIG_IGN);
+    /* should be changed to block instead of ignore */
+    hstat = SIGNAL (SIGHUP, SIG_IGN);
+    istat = SIGNAL (SIGINT, SIG_IGN);
+    qstat = SIGNAL (SIGQUIT, SIG_IGN);
+    tstat = SIGNAL (SIGTERM, SIG_IGN);
 
     rc2rc (RC_ACK, 0, NULL, rc);
 
-    signal (SIGHUP, hstat);
-    signal (SIGINT, istat);
-    signal (SIGQUIT, qstat);
-    signal (SIGTERM, tstat);
+    SIGNAL (SIGHUP, hstat);
+    SIGNAL (SIGINT, istat);
+    SIGNAL (SIGQUIT, qstat);
+    SIGNAL (SIGTERM, tstat);
 
     TTYon ();
 
     if (r->rc_len && strcmp (r->rc_data, "FAST") == 0)
 	goto no_refresh;
 
-#ifdef	SIGTSTP
-    signal (SIGTSTP, SIG_IGN);
-#endif	/* SIGTSTP */
+#ifdef SIGTSTP
+    SIGNAL (SIGTSTP, SIG_IGN);
+#endif
+
 #ifndef	TERMINFO
     if (SO)
 	tputs (SO, 0, _putchar);
@@ -507,8 +509,8 @@ pTTY (struct record *r)
     putp(exit_standout_mode);
 #endif	/* TERMINFO */
     getc (stdin);
-#ifdef	SIGTSTP
-    signal (SIGTSTP, TSTPser);
+#ifdef SIGTSTP
+    SIGNAL (SIGTSTP, TSTPser);
 #endif	/* SIGTSTP */
 
     wrefresh (curscr);
@@ -633,7 +635,7 @@ pFIN (void)
 
     switch (setjmp (PEERctx)) {
 	case OK: 
-	    signal (SIGALRM, ALRMser);
+	    SIGNAL (SIGALRM, ALRMser);
 	    alarm (ALARM);
 
 	    status = pidwait (PEERpid, OK);
@@ -666,9 +668,9 @@ WINinit (int nprog)
 	    return NOTOK;
 	else
 	    adios (NULL, "could not initialize terminal");
-#ifdef	SIGTSTP
-    signal (SIGTSTP, SIG_DFL);
-#endif	/* SIGTSTP */
+#ifdef SIGTSTP
+    SIGNAL (SIGTSTP, SIG_DFL);
+#endif /* SIGTSTP */
     sideground ();
 
 #ifndef	TERMINFO
@@ -1243,7 +1245,7 @@ TTYinit (int nprog)
 
     tty_ready = OK;
 
-    signal (SIGPIPE, PIPEser);
+    SIGNAL (SIGPIPE, PIPEser);
 
     return OK;
 }
@@ -1271,11 +1273,11 @@ TTYon (void)
 
     tty_ready = DONE;
 
-    signal (SIGHUP, SIGser);
-    signal (SIGINT, SIGser);
-    signal (SIGQUIT, SIGser);
-#ifdef	SIGTSTP
-    signal (SIGTSTP, TSTPser);
+    SIGNAL (SIGHUP, SIGser);
+    SIGNAL (SIGINT, SIGser);
+    SIGNAL (SIGQUIT, SIGser);
+#ifdef SIGTSTP
+    SIGNAL (SIGTSTP, TSTPser);
 #endif	/* SIGTSTP */
 }
 
@@ -1310,12 +1312,12 @@ TTYoff (void)
 
     tty_ready = NOTOK;
 
-    signal (SIGHUP, SIG_DFL);
-    signal (SIGINT, SIG_DFL);
-    signal (SIGQUIT, SIG_DFL);
-#ifdef	SIGTSTP
-    signal (SIGTSTP, SIG_DFL);
-#endif	/* SIGTSTP */
+    SIGNAL (SIGHUP, SIG_DFL);
+    SIGNAL (SIGINT, SIG_DFL);
+    SIGNAL (SIGQUIT, SIG_DFL);
+#ifdef SIGTSTP
+    SIGNAL (SIGTSTP, SIG_DFL);
+#endif /* SIGTSTP */
 }
 
 
@@ -1334,26 +1336,26 @@ foreground (void)
 	if (pgrp == tpgrp)
 	    break;
 
-	tstat = signal (SIGTTIN, SIG_DFL);
+	tstat = SIGNAL (SIGTTIN, SIG_DFL);
 	kill (0, SIGTTIN);
-	signal (SIGTTIN, tstat);
+	SIGNAL (SIGTTIN, tstat);
     }
     
-    signal (SIGTTIN, SIG_IGN);
-    signal (SIGTTOU, SIG_IGN);
-    signal (SIGTSTP, SIG_IGN);
-#endif	/* TIOCGPGRP */
+    SIGNAL (SIGTTIN, SIG_IGN);
+    SIGNAL (SIGTTOU, SIG_IGN);
+    SIGNAL (SIGTSTP, SIG_IGN);
+#endif /* TIOCGPGRP */
 }
 
 
 void
 sideground (void)
 {
-#ifdef	TIOCGPGRP
-    signal (SIGTTIN, SIG_DFL);
-    signal (SIGTTOU, SIG_DFL);
-    signal (SIGTSTP, SIG_DFL);
-#endif	/* TIOCGPGRP */
+#ifdef TIOCGPGRP
+    SIGNAL (SIGTTIN, SIG_DFL);
+    SIGNAL (SIGTTOU, SIG_DFL);
+    SIGNAL (SIGTSTP, SIG_DFL);
+#endif /* TIOCGPGRP */
 }
 
 /* SIGNALS */
@@ -1373,30 +1375,26 @@ ALRMser (int sig)
 static RETSIGTYPE
 PIPEser (int sig)
 {
-#ifndef	BSD42
-    signal (sig, SIG_IGN);
-#endif	/* BSD42 */
+#ifndef RELIABLE_SIGNALS
+    SIGNAL (sig, SIG_IGN);
+#endif
 
     adios (NULL, "lost peer");
 }
 
 
-#ifdef	BSD42
-/* ARGSUSED */
-#endif	/* BSD42 */
-
 static RETSIGTYPE
 SIGser (int sig)
 {
-#ifndef	BSD42
-    signal (sig, SIG_IGN);
-#endif	/* BSD42 */
+#ifndef RELIABLE_SIGNALS
+    SIGNAL (sig, SIG_IGN);
+#endif
 
     done (1);
 }
 
 
-#ifdef	SIGTSTP
+#ifdef SIGTSTP
 static RETSIGTYPE
 TSTPser (int sig)
 {
@@ -1410,20 +1408,20 @@ TSTPser (int sig)
     fflush (stdout);
 
     TTYoff ();
-#ifdef	BSD42
+#ifdef BSD42
     sigsetmask (sigblock (0) & ~sigmask (SIGTSTP));
-#endif	/* BSD42 */
+#endif /* BSD42 */
 
     kill (getpid (), sig);
 
-#ifdef	BSD42
+#ifdef BSD42
     sigblock (sigmask (SIGTSTP));
-#endif	/* BSD42 */
+#endif /* BSD42 */
     TTYon ();
 
     wrefresh (curscr);
 }
-#endif	/* SIGTSTP */
+#endif /* SIGTSTP */
 
 
 /* MISCELLANY */
