@@ -149,9 +149,9 @@ client (char *args, char *protocol, char *service, int rproto, char *response)
     for (ap = arguments; *ap; ap++) {
 	if (**ap == '\01') {
 #ifndef	BIND
-	    if (np = getnetbyname (*ap + 1)) {
+	    if ((np = getnetbyname (*ap + 1))) {
 		sethostent (1);
-		while (hp = gethostent ())
+		while ((hp = gethostent()))
 		    if (np->n_addrtype == hp->h_addrtype
 			    && inet (hp, np->n_net)) {
 			switch (sd = rcaux (sp, hp, rproto, response)) {
@@ -172,7 +172,7 @@ client (char *args, char *protocol, char *service, int rproto, char *response)
 	    continue;
 	}
 
-	if (hp = gethostbystring (*ap)) {
+	if ((hp = gethostbystring (*ap))) {
 	    switch (sd = rcaux (sp, hp, rproto, response)) {
 		case NOTOK: 
 		case OOPS1: 
