@@ -33,6 +33,8 @@
 # include <sys/file.h>
 #endif
 
+#include <signal.h>
+
 #ifdef SYS5
 # define u_short ushort
 # define u_long ulong
@@ -57,7 +59,7 @@ static void timerOFF (int);
 
 /*
  * Lock the ndbm/db file containing the Message-Id's
- * used for duplicate suppression.
+ * used for duplicate suppression in slocal.
  */
 int
 lockfile (int fd)
@@ -397,8 +399,6 @@ lkfclose (FILE *fp, char *file)
 }
 
 
-#include <signal.h>
-
 #define	NSECS ((unsigned) 20)
 
 
@@ -420,9 +420,9 @@ alrmser (int sig)
     register char *cp;
     register struct lock *lp;
 
-#ifndef	BSD42
-    signal (SIGALRM, alrmser);
-#endif	/* BSD42 */
+#ifndef	RELIABLE_SIGNALS
+    SIGNAL (SIGALRM, alrmser);
+#endif
 
     for (lp = l_top; lp; lp = lp->l_next)
 	if (*(cp = lp->l_lock) && (j = creat (cp, 0400)) != NOTOK)
@@ -452,7 +452,10 @@ timerON (char *lock, int fd)
     if (l_top)
 	lp->l_next = l_top->l_next;
     else {
-	signal (SIGALRM, alrmser);/* perhaps SIGT{STP,TIN,TOU} */
+	/*
+	 * perhaps SIGT{STP,TIN,TOU} ?
+	 */
+	SIGNAL (SIGALRM, alrmser);
 	alarm (NSECS);
     }
     l_top = lp;
