@@ -344,11 +344,11 @@ LocalName (void)
 	strcpy (buffer, localname);
     else {
 
-#ifdef	locname
+#ifdef locname
     strcpy (buffer, locname);
 #else /* not locname */
-#ifdef	NETWORK
-#ifdef	BSD41A
+#ifdef NETWORK
+#ifdef BSD41A
     myname = "myname";
     if (rhost (&myname) == -1)
 	gethostname (buffer, sizeof(buffer));
@@ -357,12 +357,12 @@ LocalName (void)
 	free (myname);
     }
 #endif /* BSD41A */
-#if	defined(BSD42) || defined(SOCKETS)
+#if defined(BSD42) || defined(SOCKETS)
     gethostname (buffer, sizeof(buffer));
 #ifndef	BIND
     sethostent (1);
 #endif
-    if (hp = gethostbyname (buffer))
+    if ((hp = gethostbyname (buffer)))
 	strcpy (buffer, hp->h_name);
 #endif /* BSD42 or SOCKETS */
 #else /* not NETWORK */
@@ -400,10 +400,10 @@ SystemName (void)
 #ifdef sysname
     strcpy (buffer, sysname);
 #else /* sysname */
-#if	!defined(SYS5) || defined(NETWORK)
+#if !defined(SYS5) || defined(NETWORK)
     gethostname (buffer, sizeof(buffer));
 #else /* SYS5 and not NETWORK */
-#ifdef	SYS5
+#ifdef SYS5
     uname (&name);
     strcpy (buffer, name.nodename);
 #endif /* SYS5 */
